# phylotrackpy: a python phylogeny tracker

[![Tests](https://github.com/emilydolson/python-phylogeny-tracker/actions/workflows/test.yml/badge.svg)](https://github.com/emilydolson/python-phylogeny-tracker/actions/workflows/test.yml)
[![Documentation Status](https://readthedocs.org/projects/phylotrackpy/badge/?version=latest)](https://phylotrackpy.readthedocs.io/en/latest/?badge=latest)
[![PyPi Package Version](https://img.shields.io/pypi/v/phylotrackpy.svg)](https://pypi.python.org/pypi/phylotrackpy)
